Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(310)

Unified Diff: sync/engine/worker_entity_tracker.h

Issue 1814823006: [Sync] Accumulate GU response chunks in the Worker. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mtw
Patch Set: Fix comment. Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « sync/engine/model_type_worker_unittest.cc ('k') | sync/engine/worker_entity_tracker.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: sync/engine/worker_entity_tracker.h
diff --git a/sync/engine/worker_entity_tracker.h b/sync/engine/worker_entity_tracker.h
index b4af987fbe28318d8158c2be6d67006e1345bf85..18374d0afe573185f8830adfdb4ef9840d72c3f5 100644
--- a/sync/engine/worker_entity_tracker.h
+++ b/sync/engine/worker_entity_tracker.h
@@ -65,19 +65,19 @@ class SYNC_EXPORT WorkerEntityTracker {
// Handles receipt of an update from the server.
void ReceiveUpdate(int64_t version);
// Handles the receipt of an pending update from the server.
//
// Returns true if the tracker decides this item is worth keeping. Returns
// false if the item is discarded, which could happen if the version number
// is out of date.
- bool ReceivePendingUpdate(const UpdateResponseData& data);
+ bool ReceiveEncryptedUpdate(const UpdateResponseData& data);
- // Functions to fetch the latest pending update.
- bool HasPendingUpdate() const;
- UpdateResponseData GetPendingUpdate() const;
+ // Functions to fetch the latest encrypted update.
+ bool HasEncryptedUpdate() const;
+ UpdateResponseData GetEncryptedUpdate() const;
- // Clears the pending update. Allows us to resume regular commit behavior.
- void ClearPendingUpdate();
+ // Clears the encrypted update. Allows us to resume regular commit behavior.
+ void ClearEncryptedUpdate();
private:
// Checks if the current state indicates a conflict.
@@ -118,7 +118,7 @@ class SYNC_EXPORT WorkerEntityTracker {
// An update for this entity which can't be applied right now. The presence
// of an pending update prevents commits. As of this writing, the only
// source of pending updates is updates that can't currently be decrypted.
- scoped_ptr<UpdateResponseData> pending_update_;
+ scoped_ptr<UpdateResponseData> encrypted_update_;
DISALLOW_COPY_AND_ASSIGN(WorkerEntityTracker);
};
« no previous file with comments | « sync/engine/model_type_worker_unittest.cc ('k') | sync/engine/worker_entity_tracker.cc » ('j') | no next file with comments »
@@ -65,19 +65,19 @@ class SYNC_EXPORT WorkerEntityTracker {
// Handles receipt of an update from the server.
void ReceiveUpdate(int64_t version);
- // Handles the receipt of an pending update from the server.
+ // Handles the receipt of an encrypted update from the server.
//
// Returns true if the tracker decides this item is worth keeping. Returns

Powered by Google App Engine
This is Rietveld 408576698